# FindMy.py

FindMy.py is a Python library aiming to provide everything you need
to interact with **Apple's FindMy Network**.
Its primary aims are feature completeness, reliability and elegant API design.
It abstracts all the heavy lifting away, while keeping the control flow in your hands.

## Jump To

[//]: # "This is hidden to prevent it from showing on the home page"

```{toctree}
:hidden:

Home <self>
```

[//]: # "Documentation can be expanded to maxdepth 2"

```{toctree}
:maxdepth: 2

getstarted/index
related/index
technical/index
reveng/index
```

[//]: # "Show these with a maxdepth of 1"

```{toctree}
:maxdepth: 1

API Reference <reference/findmy/index>
genindex
```
